==> teca-5.0.0.tar.gz: teca-5.0.0/HAMR/doc/rtd/conf.py <==
import subprocess, os

# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# http://www.sphinx-doc.org/en/master/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'HAMR'
copyright = "2022, Burlen Loring"
author = "Burlen Loring"

# -- General configuration ---------------------------------------------------


if not os.path.exists('_build/html'):
    os.makedirs('_build/html')

subprocess.call('doxygen --version', shell=True)
subprocess.call('doxygen', shell=True)

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.

# pip install sphinxcontrib-bibtex breathe
extensions = ['sphinxcontrib.bibtex', 'breathe']

bibtex_bibfiles = ['bibliography.bib']

# Configuring Breathe
breathe_projects = {
    "HAMR": "_build/xml"
}
breathe_default_project = "HAMR"

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The master toctree document.
master_doc = 'index'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_css_files = [
    'theme_overrides.css'  # overrides for wide tables in RTD theme
    ]

numfig = True

==> teca-6.0.0.tar.gz: teca-6.0.0/HAMR/doc/rtd/conf.py <==
import subprocess, os

# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# http://www.sphinx-doc.org/en/master/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'HAMR'
copyright = "2022, Burlen Loring"
author = "Burlen Loring"

# -- General configuration ---------------------------------------------------

try:
    odir = os.environ['READTHEDOCS_OUTPUT']
except:
    os.environ['READTHEDOCS_OUTPUT'] = '_build'
    odir = os.environ['READTHEDOCS_OUTPUT']

if not os.path.exists(odir + '/html'):
    os.makedirs(odir + '/html')

subprocess.call('doxygen --version', shell=True)
subprocess.call('doxygen', shell=True)

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.

# pip install sphinxcontrib-bibtex breathe
extensions = ['sphinxcontrib.bibtex', 'breathe']

bibtex_bibfiles = ['bibliography.bib']

# Configuring Breathe
breathe_projects = {
    "HAMR": "_build/xml"
}
breathe_default_project = "HAMR"

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The master toctree document.
master_doc = 'index'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_css_files = [
    'theme_overrides.css'  # overrides for wide tables in RTD theme
    ]

numfig = True
